@@ -59,6 +59,8 @@ static void       xfce_appfinder_window_finalize                      (GObject
 static void       xfce_appfinder_window_unmap                         (GtkWidget                   *widget);
 static gboolean   xfce_appfinder_window_key_press_event               (GtkWidget                   *widget,
                                                                        GdkEventKey                 *event);
+static gboolean   xfce_appfinder_window_window_state_event            (GtkWidget                   *widget,
+                                                                       GdkEventWindowState         *event);
 static void       xfce_appfinder_window_view                          (XfceAppfinderWindow         *window);
 static gboolean   xfce_appfinder_window_popup_menu                    (GtkWidget                   *view,
                                                                        XfceAppfinderWindow         *window);
@@ -178,6 +180,7 @@ xfce_appfinder_window_class_init (XfceAppfinderWindowClass *klass)
   gtkwidget_class = GTK_WIDGET_CLASS (klass);
   gtkwidget_class->unmap = xfce_appfinder_window_unmap;
   gtkwidget_class->key_press_event = xfce_appfinder_window_key_press_event;
+  gtkwidget_class->window_state_event = xfce_appfinder_window_window_state_event;
 }
 
 
@@ -236,6 +239,7 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
 
   window->icon_find = xfce_appfinder_model_load_pixbuf (GTK_STOCK_FIND, XFCE_APPFINDER_ICON_SIZE_48);
   window->image = image = gtk_image_new_from_pixbuf (window->icon_find);
+  gtk_widget_set_size_request (image, 48, 48);
   gtk_container_add (GTK_CONTAINER (align), image);
   gtk_widget_show (image);
 
@@ -356,7 +360,7 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
       G_CALLBACK (gtk_widget_destroy), window);
   gtk_widget_show (button);
 
-  window->button_launch = button = gtk_button_new_with_mnemonic ("La_unch");
+  window->button_launch = button = gtk_button_new_with_mnemonic (_("La_unch"));
   gtk_container_add (GTK_CONTAINER (bbox), button);
   g_signal_connect_swapped (G_OBJECT (button), "clicked",
       G_CALLBACK (xfce_appfinder_window_execute), window);
@@ -432,6 +436,8 @@ xfce_appfinder_window_unmap (GtkWidget *widget)
   xfconf_channel_set_int (window->channel, "/last/window-height", height);
   xfconf_channel_set_int (window->channel, "/last/window-width", width);
   xfconf_channel_set_int (window->channel, "/last/pane-position", position);
+
+  return (*GTK_WIDGET_CLASS (xfce_appfinder_window_parent_class)->unmap) (widget);
 }
 
 
@@ -495,6 +501,36 @@ xfce_appfinder_window_key_press_event (GtkWidget   *widget,
 
 
 
+static gboolean
+xfce_appfinder_window_window_state_event (GtkWidget           *widget,
+                                          GdkEventWindowState *event)
+{
+  XfceAppfinderWindow *window = XFCE_APPFINDER_WINDOW (widget);
+  gint                 width;
+
+  if (!gtk_widget_get_visible (window->paned))
+    {
+      if ((event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED) != 0)
+        {
+          gtk_window_unmaximize (GTK_WINDOW (widget));
+
+          /* set sensible width instead of taking entire width */
+          width = xfconf_channel_get_int (window->channel, "/last/window-width", DEFAULT_WINDOW_WIDTH);
+          gtk_window_resize (GTK_WINDOW (widget), width, 100 /* should be corrected by wm */);
+        }
+
+      if ((event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN) != 0)
+        gtk_window_unfullscreen (GTK_WINDOW (widget));
+    }
+
+  if ((*GTK_WIDGET_CLASS (xfce_appfinder_window_parent_class)->window_state_event) != NULL)
+    return (*GTK_WIDGET_CLASS (xfce_appfinder_window_parent_class)->window_state_event) (widget, event);
+
+  return FALSE;
+}
+
+
+
 static void
 xfce_appfinder_window_set_item_width (XfceAppfinderWindow *window)
 {
